pub struct RecognitionAudio {
pub uri: Option<String>,
pub content: Option<Vec<u8>>,
}Expand description
Contains audio data in the encoding specified in the RecognitionConfig.
Either content or uri must be supplied. Supplying both or neither
returns google.rpc.Code.INVALID_ARGUMENT. See
audio limits.
This type is not used in any activity, and only used as part of another schema.
Fields
uri: Option<String>URI that points to a file that contains audio data bytes as specified in
RecognitionConfig. Currently, only Google Cloud Storage URIs are
supported, which must be specified in the following format:
gs://bucket_name/object_name (other URI formats return
google.rpc.Code.INVALID_ARGUMENT). For more information, see
Request URIs.
content: Option<Vec<u8>>The audio data bytes encoded as specified in
RecognitionConfig. Note: as with all bytes fields, protobuffers use a
pure binary representation, whereas JSON representations use base64.