SpeechContext

Struct SpeechContext 

pub struct SpeechContext {
    pub phrases: Option<Vec<String>>,
}
Provides “hints” to the speech recognizer to favor specific words and phrases in the results.

This type is not used in any activity, and only used as part of another schema.

Fields

phrases: Option<Vec<String>>

Optional A list of strings containing words and phrases “hints” so that the speech recognition is more likely to recognize them. This can be used to improve the accuracy for specific words and phrases, for example, if specific commands are typically spoken by the user. This can also be used to add additional words to the vocabulary of the recognizer. See usage limits.