pub struct SyncRecognizeRequest {
pub config: Option<RecognitionConfig>,
pub audio: Option<RecognitionAudio>,
}Expand description
The top-level message sent by the client for the SyncRecognize method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- syncrecognize speech (request)
Fields
config: Option<RecognitionConfig>Required Provides information to the recognizer that specifies how to process the request.
audio: Option<RecognitionAudio>Required The audio data to be recognized.