pub struct SyncRecognizeResponse {
pub results: Option<Vec<SpeechRecognitionResult>>,
}Expand description
The only message returned to the client by SyncRecognize. method. It
contains the result as zero or more sequential SpeechRecognitionResult
messages.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- syncrecognize speech (response)
Fields
results: Option<Vec<SpeechRecognitionResult>>Output-only Sequential list of transcription results corresponding to sequential portions of audio.